==> ejc-technologymanage-api-3.0.0-20250929.075729-53-sources.jar: com/ejianc/business/constructor/vo/FaSealVO.java <==
package com.ejianc.business.constructor.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 施组方案用印
 * 
 * @author generator
 * 
 */
public class FaSealVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态
    private String createUserName; // 编制人
    private Long operatorId; // 经办人ID
    private String operatorName; // 经办人姓名
    private String updateUserName; // 修改者
    private String remark; // 备注
    private String famc; // 方案名称
    private Long falxId; // 方案类型id
    private String falxName; // 方案类型
    private Long gcxmmcId; // 工程项目名称id
    private String gcxmmcName; // 工程项目名称
    private Long sgdwId; // 施工单位id
    private String sgdwName; // 施工单位
    private Long ssxjzId; // 所属巡检组id
    private String ssxjzName; // 所属巡检组
    private String levelType; // 安全级别
    private String sealType; // 用印规范
    private Long sourceId; // 来源
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date serviceDate;//用印时间
    private Long projectManager;//首席服务官
    private String projectManagerName;//首席服务官名称

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public String getFamc() {
        return famc;
    }

    public void setFamc(String famc) {
        this.famc = famc;
    }
    public Long getFalxId() {
        return falxId;
    }

    public void setFalxId(Long falxId) {
        this.falxId = falxId;
    }
    public String getFalxName() {
        return falxName;
    }

    public void setFalxName(String falxName) {
        this.falxName = falxName;
    }
    public Long getGcxmmcId() {
        return gcxmmcId;
    }

    public void setGcxmmcId(Long gcxmmcId) {
        this.gcxmmcId = gcxmmcId;
    }
    public String getGcxmmcName() {
        return gcxmmcName;
    }

    public void setGcxmmcName(String gcxmmcName) {
        this.gcxmmcName = gcxmmcName;
    }
    public Long getSgdwId() {
        return sgdwId;
    }

    public void setSgdwId(Long sgdwId) {
        this.sgdwId = sgdwId;
    }
    public String getSgdwName() {
        return sgdwName;
    }

    public void setSgdwName(String sgdwName) {
        this.sgdwName = sgdwName;
    }
    public Long getSsxjzId() {
        return ssxjzId;
    }

    public void setSsxjzId(Long ssxjzId) {
        this.ssxjzId = ssxjzId;
    }
    public String getSsxjzName() {
        return ssxjzName;
    }

    public void setSsxjzName(String ssxjzName) {
        this.ssxjzName = ssxjzName;
    }
    public String getLevelType() {
        return levelType;
    }

    public void setLevelType(String levelType) {
        this.levelType = levelType;
    }
    public String getSealType() {
        return sealType;
    }

    public void setSealType(String sealType) {
        this.sealType = sealType;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }

    public Date getServiceDate() {
        return serviceDate;
    }

    public void setServiceDate(Date serviceDate) {
        this.serviceDate = serviceDate;
    }

    public Long getProjectManager() {
        return projectManager;
    }

    public void setProjectManager(Long projectManager) {
        this.projectManager = projectManager;
    }

    public String getProjectManagerName() {
        return projectManagerName;
    }

    public void setProjectManagerName(String projectManagerName) {
        this.projectManagerName = projectManagerName;
    }
}

==> ejc-technologymanage-api-3.0.0-20251128.091830-57-sources.jar: com/ejianc/business/constructor/vo/FaSealVO.java <==
package com.ejianc.business.constructor.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 施组方案用印
 * 
 * @author generator
 * 
 */
public class FaSealVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态
    private String createUserName; // 编制人
    private Long operatorId; // 经办人ID
    private String operatorName; // 经办人姓名
    private String updateUserName; // 修改者
    private String remark; // 备注
    private String famc; // 方案名称
    private Long falxId; // 方案类型id
    private String falxName; // 方案类型
    private Long gcxmmcId; // 工程项目名称id
    private String gcxmmcName; // 工程项目名称
    private Long sgdwId; // 施工单位id
    private String sgdwName; // 施工单位
    private Long ssxjzId; // 所属巡检组id
    private String ssxjzName; // 所属巡检组
    private String levelType; // 安全级别
    private String sealType; // 用印规范
    private Long sourceId; // 来源
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date serviceDate;//用印时间
    private Long projectManager;//首席服务官
    private String projectManagerName;//首席服务官名称

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public String getFamc() {
        return famc;
    }

    public void setFamc(String famc) {
        this.famc = famc;
    }
    public Long getFalxId() {
        return falxId;
    }

    public void setFalxId(Long falxId) {
        this.falxId = falxId;
    }
    public String getFalxName() {
        return falxName;
    }

    public void setFalxName(String falxName) {
        this.falxName = falxName;
    }
    @ReferSerialTransfer(referCode="project-set")
    public Long getGcxmmcId() {
        return gcxmmcId;
    }
    @ReferDeserialTransfer
    public void setGcxmmcId(Long gcxmmcId) {
        this.gcxmmcId = gcxmmcId;
    }
    public String getGcxmmcName() {
        return gcxmmcName;
    }

    public void setGcxmmcName(String gcxmmcName) {
        this.gcxmmcName = gcxmmcName;
    }
    public Long getSgdwId() {
        return sgdwId;
    }

    public void setSgdwId(Long sgdwId) {
        this.sgdwId = sgdwId;
    }
    public String getSgdwName() {
        return sgdwName;
    }

    public void setSgdwName(String sgdwName) {
        this.sgdwName = sgdwName;
    }
    public Long getSsxjzId() {
        return ssxjzId;
    }

    public void setSsxjzId(Long ssxjzId) {
        this.ssxjzId = ssxjzId;
    }
    public String getSsxjzName() {
        return ssxjzName;
    }

    public void setSsxjzName(String ssxjzName) {
        this.ssxjzName = ssxjzName;
    }
    public String getLevelType() {
        return levelType;
    }

    public void setLevelType(String levelType) {
        this.levelType = levelType;
    }
    public String getSealType() {
        return sealType;
    }

    public void setSealType(String sealType) {
        this.sealType = sealType;
    }
    @ReferSerialTransfer(referCode="tech-all")
    public Long getSourceId() {
        return sourceId;
    }
    @ReferDeserialTransfer
    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }

    public Date getServiceDate() {
        return serviceDate;
    }

    public void setServiceDate(Date serviceDate) {
        this.serviceDate = serviceDate;
    }

    public Long getProjectManager() {
        return projectManager;
    }

    public void setProjectManager(Long projectManager) {
        this.projectManager = projectManager;
    }

    public String getProjectManagerName() {
        return projectManagerName;
    }

    public void setProjectManagerName(String projectManagerName) {
        this.projectManagerName = projectManagerName;
    }
}
